package VMOMI::HostInternetScsiHbaStaticTargetTargetDiscoveryMethod;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
